==> jbossas-plugin-1.2.1-sources.jar: com/xebialabs/deployit/plugin/jbossas/step/JbossasUndeployApplicationStep.java <==
/*
 * Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of Xebialabs Software and Documentation is subject to the Personal
 * License Agreement.
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * ‚ÄúDocumentation‚Äù means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the Xebialabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to  (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.jbossas.step;

import com.xebialabs.deployit.StepExecutionContext;
import com.xebialabs.deployit.ci.artifact.Ear;
import com.xebialabs.deployit.ci.artifact.War;
import com.xebialabs.deployit.hostsession.HostFile;
import com.xebialabs.deployit.hostsession.HostSession;
import com.xebialabs.deployit.plugin.jbossas.ci.JbossasServer;

/**
 * Undeploys a {@link com.xebialabs.deployit.ci.artifact.Ear} or a {@link com.xebialabs.deployit.ci.artifact.War} from a {@link com.xebialabs.deployit.plugin.jbossas.ci.JbossasServer}
 */
@SuppressWarnings("serial")
public class JbossasUndeployApplicationStep extends JbossasDeploymentStepBase {

	public JbossasUndeployApplicationStep(JbossasServer server, Ear ear) {
		super(server, ear);
		setDescription("Undeploy EAR file " + ear + " from JBoss server " + server);
	}

	public JbossasUndeployApplicationStep(JbossasServer server, War war) {
		super(server, war);
		setDescription("Undeploy WAR file " + war + " from JBoss server " + server);
	}

	public boolean execute(StepExecutionContext ctx) {
		HostSession s = server.connectToAdminHost();
		try {
			HostFile targetFile = getArtifactTargetFile(s);

			ctx.logOutput("Removing application artifact from " + targetFile.getPath() + " on " + server.getHost());
			targetFile.delete();

			ctx.logOutput("Done.");
			return true;
		} finally {
			s.close();
		}
	}

}

==> jbossas-plugin-1.2.2-sources.jar: com/xebialabs/deployit/plugin/jbossas/step/JbossasUndeployApplicationStep.java <==
/*
 * Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to  (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.jbossas.step;

import com.xebialabs.deployit.StepExecutionContext;
import com.xebialabs.deployit.ci.artifact.Ear;
import com.xebialabs.deployit.ci.artifact.War;
import com.xebialabs.deployit.hostsession.HostFile;
import com.xebialabs.deployit.hostsession.HostSession;
import com.xebialabs.deployit.plugin.jbossas.ci.JbossasServer;

/**
 * Undeploys a {@link com.xebialabs.deployit.ci.artifact.Ear} or a {@link com.xebialabs.deployit.ci.artifact.War} from a
 * {@link com.xebialabs.deployit.plugin.jbossas.ci.JbossasServer}
 */
@SuppressWarnings("serial")
public class JbossasUndeployApplicationStep extends JbossasDeploymentStepBase {

	public JbossasUndeployApplicationStep(JbossasServer server, Ear ear) {
		super(server, ear);
		setDescription("Undeploy EAR file " + ear + " from JBoss server " + server);
	}

	public JbossasUndeployApplicationStep(JbossasServer server, War war) {
		super(server, war);
		setDescription("Undeploy WAR file " + war + " from JBoss server " + server);
	}

	public boolean execute(StepExecutionContext ctx) {
		HostSession s = server.connectToAdminHost();
		try {
			String artifactTargetFileName = getArtifactTargetFileName();
			HostFile deployDir = s.getFile(server.getDeployDirPath());
			HostFile targetDeployFile = deployDir.getFile(artifactTargetFileName);
			ctx.logOutput("Removing application artifact from " + targetDeployFile.getPath() + " on " + server.getHost());
			targetDeployFile.delete();

			ctx.logOutput("Done.");
			return true;
		} finally {
			s.close();
		}
	}

}
